@@ -9,6 +9,10 @@
 
 #include <curses.h>
 
+#ifdef C_PANELSUPPORT
+#include <panel.h>
+#endif
+
 #define C_LONGNAME
 #undef  C_LONG0ARGS
 #define C_LONG2ARGS
@@ -16,5 +20,3 @@
 #define C_TOUCHLINE
 #undef  C_TOUCH3ARGS
 #define C_TOUCH4ARGS
-
-typedef long chtype;
