@@ -8,6 +8,10 @@
 
 #include <ncurses.h>
 
+#ifdef C_PANELSUPPORT
+#include <panel.h>
+#endif
+
 #define C_LONGNAME
 #define C_LONG0ARGS
 #undef  C_LONG2ARGS
