@@ -9,6 +9,10 @@
 
 #include <ncurses.h>
 
+#ifdef C_PANELSUPPORT
+#include <panel.h>
+#endif
+
 /* Defined in both Perl & Ncurses */
 #undef instr
 
