@@ -8,6 +8,10 @@
 
 #include <curses.h>
 
+#ifdef C_PANELSUPPORT
+#include <panel.h>
+#endif
+
 #undef instr
 
 #define C_LONGNAME
